==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Submit_News/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Strona gotowa do druku");
define("_FRIEND","Wylij ten artyku do znajomych");
define("_YOURNAME","Twoje imi i nazwisko");
define("_OK","Ok!");
define("_ALLOWEDHTML","Dozwolony HTML:");
define("_EXTRANS","Zamiana (tagi html na tekst)");
define("_HTMLFORMATED","Formatowanie HTML");
define("_PLAINTEXT","Stary teskst bez formatowania");
define("_ARTICLES","Artykuy");
define("_SUBMITNEWS","Wylij newsa");
define("_SUBMITADVICE","Napisz swj artyku wypeniajc poniszy formularz i sprawd go dwa razy przed wysaniem.<br>Informujemy, i nie wszystkie artykuy s publikowane.<br>Twj artyku bdzie sprawdzony pod wzgldem gramatyki oraz moe by edytowany przez nasz zesp.");
define("_SUBTITLE","Tytu");
define("_BEDESCRIPTIVE","Pisz opisowo, jasno i prosto");
define("_BADTITLES","ze tytuy:='Sprawd to!' lub 'Artyku'");
define("_HTMLISFINE","HTML jest fajny, ale dwa razy sprawd URL-e i tagi HTML!");
define("_AREYOUSURE","Czy jeste pewien, e chcesz doczy URL? Sprawdzie jego dziaanie?");
define("_SUBPREVIEW","Musisz przejrze przed wysaniem");
define("_SELECTTOPIC","Wybierz temat");
define("_NEWSUBPREVIEW","Podgld wysyanego newsa");
define("_STORYLOOK","Twj news wyglda mniej wicej tak:");
define("_CHECKSTORY","Prosz sprawdzi tekst, linki itp. przed wysaniem newsa!");
define("_THANKSSUB","Dzikujemy za Twego newsa!");
define("_SUBSENT","Twj artyku zosta odebrany...");
define("_SUBTEXT","Sprawdzimy Twj list w cigu nastpnych kilku godzin. Jeeli bdzie interesujcy i na temat, to wkrtce go opublikujemy.");
define("_WEHAVESUB","W tym momencie mamy");
define("_WAITING","newsw oczekujcych na opublikowanie.");
define("_PREVIEW","Podgld");
define("_NEWUSER","Nowy uytkownik");
define("_USCORE","Wynik");
define("_DATE","Data");
define("_STORYTEXT","Tekst artykuu");
define("_EXTENDEDTEXT","Tekst rozszerzony");
define("_LANGUAGE","Jzyk");
define("_JANUARY","Stycze");
define("_FEBRUARY","Luty");
define("_MARCH","Marzec");
define("_APRIL","Kwiecie");
define("_MAY","Maj");
define("_JUNE","Czerwiec");
define("_JULY","Lipiec");
define("_AUGUST","Sierpie");
define("_SEPTEMBER","Wrzesie");
define("_OCTOBER","Padziernik");
define("_NOVEMBER","Listopad");
define("_DECEMBER","Grudzie");
define("_SELECTMONTH2VIEW","Prosz wybra miesic ktry chcesz przejrze:");
define("_SHOWALLSTORIES","Poka WSZYSTKIE artykuy");
define("_STORIESARCHIVE","Archiwum artykuw");
define("_ACTIONS","Akcje");
define("_ARCHIVESINDEX","Wykaz archiwum artykuw");
define("_ALLSTORIESARCH","Wszystkie artykuy");
define("_NEXTPAGE","Nastpna strona");
define("_PREVIOUSPAGE","Poprzednia strona");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Submit_News/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Strona gotowa do druku");
define("_FRIEND","Wylij ten artyku do znajomych");
define("_YOURNAME","Twoje imi i nazwisko");
define("_OK","Ok!");
define("_ALLOWEDHTML","Dozwolony HTML:");
define("_EXTRANS","Zamiana (tagi html na tekst)");
define("_HTMLFORMATED","Formatowanie HTML");
define("_PLAINTEXT","Stary teskst bez formatowania");
define("_ARTICLES","Artykuy");
define("_SUBMITNEWS","Wylij newsa");
define("_SUBMITADVICE","Napisz swj artyku wypeniajc poniszy formularz i sprawd go dwa razy przed wysaniem.<br>Informujemy, i nie wszystkie artykuy s publikowane.<br>Twj artyku bdzie sprawdzony pod wzgldem gramatyki oraz moe by edytowany przez nasz zesp.");
define("_SUBTITLE","Tytu");
define("_BEDESCRIPTIVE","Pisz opisowo, jasno i prosto");
define("_BADTITLES","ze tytuy:='Sprawd to!' lub 'Artyku'");
define("_HTMLISFINE","HTML jest fajny, ale dwa razy sprawd URL-e i tagi HTML!");
define("_AREYOUSURE","Czy jeste pewien, e chcesz doczy URL? Sprawdzie jego dziaanie?");
define("_SUBPREVIEW","Musisz przejrze przed wysaniem");
define("_SELECTTOPIC","Wybierz temat");
define("_NEWSUBPREVIEW","Podgld wysyanego newsa");
define("_STORYLOOK","Twj news wyglda mniej wicej tak:");
define("_CHECKSTORY","Prosz sprawdzi tekst, linki itp. przed wysaniem newsa!");
define("_THANKSSUB","Dzikujemy za Twego newsa!");
define("_SUBSENT","Twj artyku zosta odebrany...");
define("_SUBTEXT","Sprawdzimy Twj list w cigu nastpnych kilku godzin. Jeeli bdzie interesujcy i na temat, to wkrtce go opublikujemy.");
define("_WEHAVESUB","W tym momencie mamy");
define("_WAITING","newsw oczekujcych na opublikowanie.");
define("_PREVIEW","Podgld");
define("_NEWUSER","Nowy uytkownik");
define("_USCORE","Wynik");
define("_DATE","Data");
define("_STORYTEXT","Tekst artykuu");
define("_EXTENDEDTEXT","Tekst rozszerzony");
define("_LANGUAGE","Jzyk");

define("_SELECTMONTH2VIEW","Prosz wybra miesic ktry chcesz przejrze:");
define("_SHOWALLSTORIES","Poka WSZYSTKIE artykuy");
define("_STORIESARCHIVE","Archiwum artykuw");
define("_ACTIONS","Akcje");
define("_ARCHIVESINDEX","Wykaz archiwum artykuw");
define("_ALLSTORIESARCH","Wszystkie artykuy");
define("_NEXTPAGE","Nastpna strona");
define("_PREVIOUSPAGE","Poprzednia strona");

?>
